@@ -1,6 +1,6 @@
 package JIRA::REST;
 # ABSTRACT: Thin wrapper around JIRA's REST API
-$JIRA::REST::VERSION = '0.014';
+$JIRA::REST::VERSION = '0.015';
 use 5.008_008;
 use utf8;
 use strict;
@@ -25,10 +25,13 @@ sub new {
         croak __PACKAGE__ . "::new: URL argument must be an URI object.\n";
     }
 
+    my $path = $URL->path('');
     # See if the user wants a specific JIRA Core REST API version:
-    my $path = $URL->path('') || '/rest/api/latest';
-    $path =~ m@^/rest/api/(?:latest|\d+)$@
-        or croak __PACKAGE__ . "::new: invalid path in URL: '$path'\n";
+    if ($path =~ m@^/?$@) {
+        $path = '/rest/api/latest';
+    } elsif ($path !~ m@^/rest/api/(?:latest|\d+)$@) {
+        croak __PACKAGE__ . "::new: invalid path in URL: '$path'\n";
+    }
 
     # If username and password are not set we try to lookup the credentials
     if (! defined $username || ! defined $password) {
@@ -342,7 +345,7 @@ JIRA::REST - Thin wrapper around JIRA's REST API
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
